@@ -4,8 +4,8 @@ $self = {
           'deps' => [
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/gobject-introspection-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -pthread -I/usr/lib/libffi-3.2.1/include  -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  -I/usr/lib/libffi-3.2.1/include ',
-          'libs' => '-lgirepository-1.0 -lgobject-2.0 -lglib-2.0  -Wl,--export-dynamic -lgmodule-2.0 -pthread -lglib-2.0  -lffi ',
+          'inc' => '-I/usr/include/gobject-introspection-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/lib/libffi-3.2.1/include -pthread  -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include  -I/usr/lib/libffi-3.2.1/include ',
+          'libs' => '-lgirepository-1.0 -lgobject-2.0 -lglib-2.0  -Wl,--export-dynamic -pthread -lgmodule-2.0 -lglib-2.0  -lffi ',
           'typemaps' => []
         };
 
